<?php
if (!defined('ABSPATH')) {
  exit;
}

// Add menu pages
add_action('admin_menu', 'hai_add_admin_menu');
function hai_add_admin_menu()
{
  add_menu_page(
    __('Hai Support', 'hai-support'),
    __('Hai Support', 'hai-support'),
    'manage_options',
    'hai-support',
    'hai_render_dashboard',
    'dashicons-format-chat',
    30
  );

  add_submenu_page(
    'hai-support',
    __('Settings', 'hai-support'),
    __('Settings', 'hai-support'),
    'manage_options',
    'hai-support-settings',
    'hai_render_settings'
  );
}

// Enqueue admin scripts and styles
add_action('admin_enqueue_scripts', 'hai_admin_enqueue_scripts');
function hai_admin_enqueue_scripts($hook)
{
  // Check if we're on any Hai Support admin page
  if (strpos($hook, 'hai-support') === false) {
    return;
  }

  wp_enqueue_style(
    'hai-admin-style',
    HAI_SUPPORT_PLUGIN_URL . 'assets/css/hai.css',
    array(),
    HAI_SUPPORT_VERSION
  );

  wp_enqueue_script(
    'hai-admin-script',
    HAI_SUPPORT_PLUGIN_URL . 'assets/js/hai-admin.js',
    array('jquery'),
    HAI_SUPPORT_VERSION,
    true
  );

  wp_localize_script('hai-admin-script', 'haiAdmin', array(
    'nonce' => wp_create_nonce('hai-admin-nonce'),
    'botName' => hai_get_setting('hai_bot_name'),
    'pluginUrl' => HAI_SUPPORT_PLUGIN_URL,
    'agentAvatar' => hai_get_setting('hai_agent_avatar') ? HAI_SUPPORT_PLUGIN_URL . 'assets/images/avatars/' . hai_get_setting('hai_agent_avatar') : '',
    'i18n' => array(
      'enterApiKey' => __('Please enter an API key first.', 'hai-support'),
      'invalidApiKey' => __('Invalid API key format. The API key should start with "sk-" followed by a long string of characters.', 'hai-support'),
      'validating' => __('Validating...', 'hai-support'),
      'validationError' => __('An error occurred while validating the API key.', 'hai-support'),
      'configured' => __('Configured', 'hai-support'),
      'required' => __('Required', 'hai-support'),
      'analyzingContent' => __('Analyzing website content...', 'hai-support'),
      'gatheringInfo' => __('Gathering website information...', 'hai-support'),
      'promptError' => __('An error occurred while generating the prompt.', 'hai-support'),
      'promptReviewWarning' => __('⚠️ Important: Please review and customize this generated prompt before saving. The AI assistant will use this exact prompt to interact with your users. Make sure it accurately represents your website, services, and desired interaction style.', 'hai-support')
    )
  ));
}

// Enqueue frontend scripts and styles
add_action('wp_enqueue_scripts', 'hai_frontend_enqueue_scripts');
function hai_frontend_enqueue_scripts()
{
  // Explicitly check if the setting is true
  if (hai_get_setting('hai_enable_chat') !== true) {
    return;
  }

  wp_enqueue_style(
    'hai-chat-style',
    HAI_SUPPORT_PLUGIN_URL . 'assets/css/hai.css',
    array(),
    HAI_SUPPORT_VERSION
  );

  wp_enqueue_script(
    'hai-chat-script',
    HAI_SUPPORT_PLUGIN_URL . 'assets/js/hai-chat.js',
    array('jquery'),
    HAI_SUPPORT_VERSION,
    true
  );

  wp_localize_script('hai-chat-script', 'haiChat', array(
    'ajaxUrl' => admin_url('admin-ajax.php'),
    'nonce' => wp_create_nonce('hai-chat-nonce'),
    'botName' => hai_get_setting('hai_bot_name'),
    'themeColor' => hai_get_setting('hai_theme_color')
  ));
}

// Add chat widget to footer
add_action('wp_footer', 'hai_add_chat_widget');
function hai_add_chat_widget()
{
  // Explicitly check if the setting is true
  if (hai_get_setting('hai_enable_chat') !== true) {
    return;
  }

  require_once HAI_SUPPORT_PLUGIN_DIR . 'templates/chatbox.php';
}

// AJAX action for admin nonce
add_action('wp_ajax_hai_admin_nonce', 'hai_admin_nonce');
function hai_admin_nonce()
{
  wp_send_json_success(wp_create_nonce('hai-admin-nonce'));
}

// AJAX action for OpenAI API key validation
add_action('wp_ajax_hai_validate_api_key', 'hai_validate_api_key');
function hai_validate_api_key()
{
  if (!current_user_can('manage_options')) {
    wp_send_json_error(array(
      'message' => __('You do not have permission to perform this action.', 'hai-support')
    ));
  }

  if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'hai-admin-nonce')) {
    wp_send_json_error(array(
      'message' => __('Invalid security token. Please refresh the page and try again.', 'hai-support')
    ));
  }

  $api_key = isset($_POST['api_key']) ? sanitize_text_field($_POST['api_key']) : '';

  if (empty($api_key)) {
    wp_send_json_error(array(
      'message' => __('Please enter an API key.', 'hai-support')
    ));
  }

  // Validate API key format - updated to handle both old and new formats
  if (!preg_match('/^sk-[a-zA-Z0-9-_]{32,}$/', $api_key)) {
    wp_send_json_error(array(
      'message' => __('Invalid API key format. The API key should start with "sk-" followed by a long string of characters.', 'hai-support')
    ));
  }

  // Test the API key with a simple models list request
  $response = wp_remote_get('https://api.openai.com/v1/models', array(
    'headers' => array(
      'Authorization' => 'Bearer ' . $api_key,
      'Content-Type' => 'application/json'
    ),
    'timeout' => 15,
    'sslverify' => true
  ));

  if (is_wp_error($response)) {
    wp_send_json_error(array(
      'message' => sprintf(
        __('Error connecting to OpenAI: %s', 'hai-support'),
        $response->get_error_message()
      )
    ));
  }

  $body = json_decode(wp_remote_retrieve_body($response), true);
  $status = wp_remote_retrieve_response_code($response);

  if ($status === 200 && isset($body['data']) && is_array($body['data'])) {
    // Save the validated API key
    update_option('hai_openai_api_key', $api_key);

    wp_send_json_success(array(
      'message' => __('API key is valid and has been saved.', 'hai-support')
    ));
  } else {
    $error_message = isset($body['error']['message'])
      ? $body['error']['message']
      : __('Unknown error occurred while validating the API key.', 'hai-support');

    wp_send_json_error(array(
      'message' => $error_message
    ));
  }
}

// AJAX action for generating custom prompt
add_action('wp_ajax_hai_generate_prompt', 'hai_generate_prompt');
function hai_generate_prompt()
{
  if (!current_user_can('manage_options')) {
    wp_send_json_error(array(
      'message' => __('You do not have permission to perform this action.', 'hai-support')
    ));
  }

  if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'hai-admin-nonce')) {
    wp_send_json_error(array(
      'message' => __('Invalid security token. Please refresh the page and try again.', 'hai-support')
    ));
  }

  global $wpdb;

  // Get site information
  $site_name = get_bloginfo('name');
  $site_description = get_bloginfo('description');
  $home_url = home_url();

  // Get important system URLs
  $system_urls = array(
    'login' => wp_login_url(),
    'register' => wp_registration_url(),
    'lost_password' => wp_lostpassword_url(),
    'privacy_policy' => get_privacy_policy_url(),
    'admin_email' => get_option('admin_email')
  );

  // Get menu items to find important pages
  $menu_items = wp_get_nav_menu_items(get_nav_menu_locations()['primary'] ?? 0);
  $menu_urls = array();
  if ($menu_items) {
    foreach ($menu_items as $item) {
      $menu_urls[$item->title] = $item->url;
    }
  }

  // Get all published pages with their content
  $pages = $wpdb->get_results(
    "SELECT ID, post_title, post_content, post_name 
    FROM {$wpdb->posts} 
    WHERE post_type = 'page' 
    AND post_status = 'publish'"
  );

  // Prepare page data for analysis
  $pages_data = array();
  foreach ($pages as $page) {
    $content = wp_strip_all_tags($page->post_content);
    $content = preg_replace('/[\r\n\t]+/', ' ', $content); // Clean up whitespace
    $content = preg_replace('/\s+/', ' ', $content); // Normalize spaces

    $pages_data[] = array(
      'title' => $page->post_title,
      'url' => get_permalink($page->ID),
      'content' => $content
    );
  }

  // Get WooCommerce data and URLs if active
  $woo_data = '';
  $woo_urls = array();
  if (class_exists('WooCommerce')) {
    // Get WooCommerce specific URLs
    $woo_urls = array(
      'shop' => wc_get_page_permalink('shop'),
      'cart' => wc_get_cart_url(),
      'checkout' => wc_get_checkout_url(),
      'my_account' => wc_get_page_permalink('myaccount'),
      'orders' => wc_get_account_endpoint_url('orders'),
      'downloads' => wc_get_account_endpoint_url('downloads'),
      'track_order' => wc_get_endpoint_url('order-tracking')
    );

    $products = $wpdb->get_results(
      "SELECT post_title, post_content 
      FROM {$wpdb->posts} 
      WHERE post_type = 'product' 
      AND post_status = 'publish' 
      LIMIT 10"
    );

    if (!empty($products)) {
      $woo_data = "Sample products:\n";
      foreach ($products as $product) {
        $woo_data .= "- " . $product->post_title . "\n";
      }
    }
  }

  // Prepare data for OpenAI analysis
  $analysis_prompt = "Analyze the following website content and create a comprehensive support agent prompt. Include key information about services, products, and important pages.\n\n";
  $analysis_prompt .= "Website: {$site_name}\n";
  $analysis_prompt .= "Description: {$site_description}\n\n";

  // Add system URLs
  $analysis_prompt .= "System URLs:\n";
  $analysis_prompt .= "- Login: {$system_urls['login']}\n";
  $analysis_prompt .= "- Register: {$system_urls['register']}\n";
  $analysis_prompt .= "- Reset Password: {$system_urls['lost_password']}\n";
  if ($system_urls['privacy_policy']) {
    $analysis_prompt .= "- Privacy Policy: {$system_urls['privacy_policy']}\n";
  }
  $analysis_prompt .= "- Support Email: {$system_urls['admin_email']}\n";

  // Add menu URLs if available
  if (!empty($menu_urls)) {
    $analysis_prompt .= "\nMenu Links:\n";
    foreach ($menu_urls as $title => $url) {
      $analysis_prompt .= "- {$title}: {$url}\n";
    }
  }

  // Add WooCommerce URLs if available
  if (!empty($woo_urls)) {
    $analysis_prompt .= "\nE-commerce URLs:\n";
    foreach ($woo_urls as $key => $url) {
      $analysis_prompt .= "- " . ucwords(str_replace('_', ' ', $key)) . ": {$url}\n";
    }
  }

  $analysis_prompt .= "\nPages Content:\n";
  foreach ($pages_data as $page) {
    $analysis_prompt .= "\nPage: {$page['title']}\nURL: {$page['url']}\nContent Summary: {$page['content']}\n";
  }

  if (!empty($woo_data)) {
    $analysis_prompt .= "\nE-commerce Information:\n" . $woo_data;
  }

  $analysis_prompt .= "\nBased on this content, create a detailed prompt for an AI customer support agent. Include:\n";
  $analysis_prompt .= "1. Main purpose and services of the website\n";
  $analysis_prompt .= "2. Key pages and their purposes\n";
  $analysis_prompt .= "3. Products or services offered\n";
  $analysis_prompt .= "4. Common customer queries and how to handle them\n";
  $analysis_prompt .= "5. Specific guidelines for interacting with customers\n";
  $analysis_prompt .= "6. Instructions for directing users to appropriate URLs for common tasks (login, password reset, etc.)\n";
  $analysis_prompt .= "Format the response as a ready-to-use prompt. Include the URLs in your response so the AI can direct users to the right pages.";

  // Get API key
  $api_key = hai_get_setting('hai_openai_api_key');

  if (empty($api_key)) {
    wp_send_json_error(array(
      'message' => __('OpenAI API key is not configured.', 'hai-support')
    ));
  }

  // Call OpenAI API to generate the prompt
  $response = wp_remote_post('https://api.openai.com/v1/chat/completions', array(
    'headers' => array(
      'Authorization' => 'Bearer ' . $api_key,
      'Content-Type' => 'application/json'
    ),
    'body' => wp_json_encode(array(
      'model' => 'gpt-4',
      'messages' => array(
        array(
          'role' => 'system',
          'content' => 'You are a prompt engineering expert. Create concise but comprehensive prompts for AI customer support agents.'
        ),
        array(
          'role' => 'user',
          'content' => $analysis_prompt
        )
      ),
      'temperature' => 0.7,
      'max_tokens' => 1000
    )),
    'timeout' => 30
  ));

  if (is_wp_error($response)) {
    wp_send_json_error(array(
      'message' => $response->get_error_message()
    ));
  }

  $body = json_decode(wp_remote_retrieve_body($response), true);

  if (!empty($body['choices'][0]['message']['content'])) {
    $generated_prompt = $body['choices'][0]['message']['content'];

    // Add standard guidelines to the generated prompt
    $generated_prompt .= "\n\nGeneral Guidelines:\n";
    $generated_prompt .= "1. Be friendly, professional, and helpful\n";
    $generated_prompt .= "2. If you don't know something, admit it and suggest contacting support directly\n";
    $generated_prompt .= "3. Keep responses concise but informative\n";
    $generated_prompt .= "4. For sensitive information or account-specific issues, direct users to the contact page\n";
    $generated_prompt .= "5. Maintain a positive and solution-oriented tone\n";

    wp_send_json_success(array(
      'prompt' => $generated_prompt,
      'message' => __('Custom prompt generated successfully!', 'hai-support')
    ));
  } else {
    wp_send_json_error(array(
      'message' => __('Failed to generate prompt. Please try again.', 'hai-support')
    ));
  }
}
