<?php

/**
 * Plugin Name: Hai Support
 * Plugin URI: https://omniflux.co.uk/hai-support/
 * Description: Add an AI-powered chat support widget to your WordPress site using OpenAI's GPT models. Provide instant, context-aware responses to your visitors' questions.
 * Version: 1.0.0
 * Author: Omniflux
 * Author URI: https://omniflux.co.uk
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: hai-support
 * Domain Path: /languages
 */

if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly
}

// Define plugin constants
define('HAI_SUPPORT_VERSION', '1.0.0');
define('HAI_SUPPORT_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('HAI_SUPPORT_PLUGIN_URL', plugin_dir_url(__FILE__));

// Include required files
require_once HAI_SUPPORT_PLUGIN_DIR . 'hai-support-functions.php';
require_once HAI_SUPPORT_PLUGIN_DIR . 'hai-support-hooks.php';
require_once HAI_SUPPORT_PLUGIN_DIR . 'includes/class-hai-chat.php';
require_once HAI_SUPPORT_PLUGIN_DIR . 'includes/class-hai-admin.php';
require_once HAI_SUPPORT_PLUGIN_DIR . 'includes/class-hai-db.php';
require_once HAI_SUPPORT_PLUGIN_DIR . 'includes/class-hai-api.php';

// Initialize the plugin
function hai_support_init()
{
  // Initialize classes
  new Hai_Chat();
  new Hai_Admin();
  new Hai_DB();
  new Hai_API();
}
add_action('plugins_loaded', 'hai_support_init');

// Activation hook
register_activation_hook(__FILE__, 'hai_support_activate');
function hai_support_activate()
{
  require_once HAI_SUPPORT_PLUGIN_DIR . 'includes/class-hai-db.php';
  $db = new Hai_DB();
  $db->create_tables();
}

// Deactivation hook
register_deactivation_hook(__FILE__, 'hai_support_deactivate');
function hai_support_deactivate()
{
  // Cleanup tasks if needed
}
