<?php
if (!defined('ABSPATH')) {
  exit;
}

class Hai_DB
{
  private $table_name;

  public function __construct()
  {
    global $wpdb;
    $this->table_name = $wpdb->prefix . 'hai_conversations';
  }

  public function create_tables()
  {
    global $wpdb;
    $charset_collate = $wpdb->get_charset_collate();

    // Main conversations table
    $sql = "CREATE TABLE IF NOT EXISTS {$this->table_name} (
            id bigint(20) UNSIGNED NOT NULL AUTO_INCREMENT,
            user_name varchar(255) DEFAULT NULL,
            session_id varchar(45) NOT NULL,
            user_ip varchar(45) NOT NULL,
            user_location text DEFAULT NULL,
            user_agent text DEFAULT NULL,
            conversation longtext NOT NULL,
            status enum('unread','read') DEFAULT 'unread',
            created_at datetime DEFAULT CURRENT_TIMESTAMP,
            updated_at datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
            PRIMARY KEY (id),
            KEY session_id (session_id),
            KEY status (status)
        ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);
  }

  public function insert_conversation($data)
  {
    global $wpdb;

    $defaults = array(
      'user_name' => null,
      'session_id' => '',
      'user_ip' => '',
      'user_location' => null,
      'user_agent' => null,
      'conversation' => '[]',
      'status' => 'unread'
    );

    $data = wp_parse_args($data, $defaults);

    return $wpdb->insert($this->table_name, $data);
  }

  public function update_conversation($id, $data)
  {
    global $wpdb;

    // Ensure id is an integer
    $id = intval($id);
    if (!$id) {
      return false;
    }

    // Ensure we have valid data to update
    if (empty($data) || !is_array($data)) {
      return false;
    }

    // If updating conversation field, ensure it's valid JSON
    if (isset($data['conversation'])) {
      $json = json_decode($data['conversation']);
      if (json_last_error() !== JSON_ERROR_NONE) {
        return false;
      }
    }

    // Always update the updated_at timestamp
    if (!isset($data['updated_at'])) {
      $data['updated_at'] = current_time('mysql');
    }

    return $wpdb->update(
      $this->table_name,
      $data,
      array('id' => $id)
    );
  }

  public function get_conversation($id)
  {
    global $wpdb;
    return $wpdb->get_row($wpdb->prepare(
      "SELECT * FROM {$this->table_name} WHERE id = %d",
      $id
    ));
  }

  public function get_conversations($args = array())
  {
    global $wpdb;

    $defaults = array(
      'session_id' => null,
      'status' => null,
      'limit' => 20,
      'offset' => 0,
      'orderby' => 'created_at',
      'order' => 'DESC'
    );

    $args = wp_parse_args($args, $defaults);

    $where = "WHERE 1=1";
    if ($args['status']) {
      $where .= $wpdb->prepare(" AND status = %s", $args['status']);
    }
    if ($args['session_id']) {
      $where .= $wpdb->prepare(" AND session_id = %s", $args['session_id']);
    }

    $orderby = sanitize_sql_orderby("{$args['orderby']} {$args['order']}");

    return $wpdb->get_results($wpdb->prepare(
      "SELECT * FROM {$this->table_name} 
            {$where} 
            ORDER BY {$orderby}
            LIMIT %d OFFSET %d",
      $args['limit'],
      $args['offset']
    ));
  }

  public function delete_conversation($id)
  {
    global $wpdb;
    return $wpdb->delete($this->table_name, array('id' => $id));
  }
}
