<?php
if (!defined('ABSPATH')) {
  exit;
}

$title = __('Settings', 'hai-support');
require_once HAI_SUPPORT_PLUGIN_DIR . 'templates/admin-header.php';
?>
<div class="wrap">
  <div class="hai-max-w-4xl hai-mx-auto">
    <?php settings_errors('hai_settings'); ?>

    <!-- Settings Form -->
    <div class="hai-bg-white hai-rounded-xl hai-shadow-sm hai-border hai-border-gray-200 hai-overflow-hidden">
      <form method="post" action="" class="hai-divide-y hai-divide-gray-200">
        <?php wp_nonce_field('hai_save_settings', 'hai_settings_nonce'); ?>

        <!-- Required Settings Section -->
        <div class="hai-p-6 lg:hai-p-8">
          <div class="hai-flex hai-items-start hai-gap-4 hai-mb-6">
            <div class="hai-flex-shrink-0 hai-w-12 hai-h-12 hai-rounded-xl <?php echo !empty(hai_get_setting('hai_openai_api_key')) && !empty(hai_get_setting('hai_ai_model')) ? 'hai-bg-green-100' : 'hai-bg-red-100'; ?> hai-flex hai-items-center hai-justify-center">
              <svg class="hai-w-6 hai-h-6 <?php echo !empty(hai_get_setting('hai_openai_api_key')) && !empty(hai_get_setting('hai_ai_model')) ? 'hai-text-green-600' : 'hai-text-red-600'; ?>" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <?php if (!empty(hai_get_setting('hai_openai_api_key')) && !empty(hai_get_setting('hai_ai_model'))): ?>
                  <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" d="M5 13l4 4L19 7"></path>
                <?php else: ?>
                  <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" d="M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-3L13.732 4c-.77-1.333-2.694-1.333-3.464 0L3.34 16c-.77 1.333.192 3 1.732 3z"></path>
                <?php endif; ?>
              </svg>
            </div>
            <div>
              <h3 class="hai-text-lg hai-font-semibold hai-text-gray-900 hai-m-0 hai-p-0"><?php echo esc_html__('Required Settings', 'hai-support'); ?></h3>
              <p class="hai-mt-1 hai-text-sm hai-text-gray-500 hai-m-0 hai-p-0">
                <?php if (!empty(hai_get_setting('hai_openai_api_key')) && !empty(hai_get_setting('hai_ai_model'))): ?>
                  <?php echo esc_html__('All required settings are configured.', 'hai-support'); ?>
                <?php else: ?>
                  <?php echo esc_html__('These settings must be configured for the chat widget to work.', 'hai-support'); ?>
                <?php endif; ?>
              </p>
            </div>
          </div>

          <div class="hai-space-y-6">
            <!-- OpenAI API Key -->
            <div class="hai-bg-<?php echo !empty(hai_get_setting('hai_openai_api_key')) ? 'green' : 'red'; ?>-50 hai-p-6 hai-rounded-xl hai-border hai-border-<?php echo !empty(hai_get_setting('hai_openai_api_key')) ? 'green' : 'red'; ?>-100">
              <label for="hai_openai_api_key" class="hai-block hai-text-sm hai-font-medium hai-text-gray-900">
                <?php echo esc_html__('OpenAI API Key', 'hai-support'); ?>
                <span class="hai-text-<?php echo !empty(hai_get_setting('hai_openai_api_key')) ? 'green' : 'red'; ?>-600">*</span>
                <span class="hai-ml-2 hai-inline-flex hai-items-center hai-px-2 hai-py-0.5 hai-rounded-lg hai-text-xs hai-font-medium hai-bg-<?php echo !empty(hai_get_setting('hai_openai_api_key')) ? 'green' : 'red'; ?>-100 hai-text-<?php echo !empty(hai_get_setting('hai_openai_api_key')) ? 'green' : 'red'; ?>-800">
                  <?php echo !empty(hai_get_setting('hai_openai_api_key')) ? 'Configured' : 'Required'; ?>
                </span>
              </label>
              <div class="hai-mt-3 hai-flex hai-items-center hai-gap-3">
                <div class="hai-flex-1">
                  <input type="text"
                    name="hai_openai_api_key"
                    id="hai_openai_api_key"
                    value="<?php echo esc_attr(hai_get_setting('hai_openai_api_key')); ?>"
                    class="hai-block hai-w-full hai-rounded-lg hai-border-gray-300 focus:hai-border-[#6e00ff] focus:hai-ring-[#6e00ff] hai-text-sm hai-font-mono hai-bg-white"
                    placeholder="<?php echo esc_attr__('sk-...', 'hai-support'); ?>"
                    required>
                </div>
                <button type="button"
                  id="hai-validate-api-key"
                  class="hai-inline-flex hai-items-center hai-rounded-lg hai-bg-[#6e00ff] hai-px-4 hai-py-2 hai-text-sm hai-font-medium hai-text-white hai-transition-all hai-duration-200 hover:hai-bg-[#5b00d6] hover:hai-translate-y-[-1px] hover:hai-shadow-[0_4px_8px_-2px_rgba(110,0,255,0.3)] focus:hai-outline-none hai-border-0 hai-cursor-pointer hai-m-0">
                  <svg class="hai-w-4 hai-h-4 hai-mr-1.5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"></path>
                  </svg>
                  <?php echo esc_html__('Validate Key', 'hai-support'); ?>
                </button>
              </div>
              <div id="api-key-status" class="hai-mt-3 hai-text-sm"></div>
              <p class="hai-mt-3 hai-text-sm hai-text-gray-600">
                <?php echo esc_html__('Required for AI chat functionality. Get your API key from', 'hai-support'); ?>
                <a href="https://platform.openai.com/api-keys" target="_blank" class="hai-text-[#6e00ff] hai-underline">OpenAI</a>.
              </p>
            </div>

            <!-- AI Model -->
            <div class="hai-bg-<?php echo !empty(hai_get_setting('hai_ai_model')) ? 'green' : 'red'; ?>-50 hai-p-6 hai-rounded-xl hai-border hai-border-<?php echo !empty(hai_get_setting('hai_ai_model')) ? 'green' : 'red'; ?>-100">
              <label for="hai_ai_model" class="hai-block hai-text-sm hai-font-medium hai-text-gray-900">
                <?php echo esc_html__('AI Model', 'hai-support'); ?>
                <span class="hai-text-<?php echo !empty(hai_get_setting('hai_ai_model')) ? 'green' : 'red'; ?>-600">*</span>
                <span class="hai-ml-2 hai-inline-flex hai-items-center hai-px-2 hai-py-0.5 hai-rounded-lg hai-text-xs hai-font-medium hai-bg-<?php echo !empty(hai_get_setting('hai_ai_model')) ? 'green' : 'red'; ?>-100 hai-text-<?php echo !empty(hai_get_setting('hai_ai_model')) ? 'green' : 'red'; ?>-800">
                  <?php echo !empty(hai_get_setting('hai_ai_model')) ? 'Configured' : 'Required'; ?>
                </span>
              </label>
              <div class="hai-mt-3">
                <select name="hai_ai_model"
                  id="hai_ai_model"
                  class="hai-block hai-w-full hai-rounded-lg hai-border hai-border-gray-300 focus:hai-border-[#6e00ff] focus:hai-ring-[#6e00ff] hai-text-sm hai-m-0 hai-px-3 hai-py-2 hai-bg-white hai-appearance-none"
                  required>
                  <option value="gpt-4" <?php selected(hai_get_setting('hai_ai_model'), 'gpt-4'); ?>>
                    GPT-4 (Recommended)
                  </option>
                  <option value="gpt-3.5-turbo" <?php selected(hai_get_setting('hai_ai_model'), 'gpt-3.5-turbo'); ?>>
                    GPT-3.5 Turbo (Faster, more affordable)
                  </option>
                </select>
              </div>
              <p class="hai-mt-3 hai-text-sm hai-text-gray-600">
                <?php echo esc_html__('Select the AI model for chat responses. GPT-4 offers better quality but costs more.', 'hai-support'); ?>
              </p>
            </div>
          </div>
        </div>

        <!-- Basic Settings Section -->
        <div class="hai-p-6 lg:hai-p-8">
          <div class="hai-flex hai-items-start hai-gap-4 hai-mb-6">
            <div class="hai-flex-shrink-0 hai-w-12 hai-h-12 hai-rounded-xl hai-bg-blue-100 hai-flex hai-items-center hai-justify-center">
              <svg class="hai-w-6 hai-h-6 hai-text-blue-600" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" d="M10.325 4.317c.426-1.756 2.924-1.756 3.35 0a1.724 1.724 0 002.573 1.066c1.543-.94 3.31.826 2.37 2.37a1.724 1.724 0 001.065 2.572c1.756.426 1.756 2.924 0 3.35a1.724 1.724 0 00-1.066 2.573c.94 1.543-.826 3.31-2.37 2.37a1.724 1.724 0 00-2.572 1.065c-.426 1.756-2.924 1.756-3.35 0a1.724 1.724 0 00-2.573-1.066c-1.543.94-3.31-.826-2.37-2.37a1.724 1.724 0 00-1.065-2.572c-1.756-.426-1.756-2.924 0-3.35a1.724 1.724 0 001.066-2.573c-.94-1.543.826-3.31 2.37-2.37.996.608 2.296.07 2.572-1.065z"></path>
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" d="M15 12a3 3 0 11-6 0 3 3 0 016 0z"></path>
              </svg>
            </div>
            <div>
              <h3 class="hai-text-lg hai-font-semibold hai-text-gray-900 hai-m-0 hai-p-0"><?php echo esc_html__('Basic Settings', 'hai-support'); ?></h3>
              <p class="hai-mt-1 hai-text-sm hai-text-gray-500 hai-m-0 hai-p-0"><?php echo esc_html__('Configure basic settings for the chat widget.', 'hai-support'); ?></p>
            </div>
          </div>

          <div class="hai-space-y-6">
            <!-- Enable Chat -->
            <div class="hai-bg-blue-50 hai-p-6 hai-rounded-xl hai-border hai-border-blue-100">
              <div class="hai-flex hai-items-start">
                <div class="hai-flex hai-items-center hai-h-5">
                  <input type="checkbox"
                    name="hai_enable_chat"
                    id="hai_enable_chat"
                    value="1"
                    <?php checked(hai_get_setting('hai_enable_chat')); ?>
                    class="hai-h-5 hai-w-5 hai-rounded hai-border-gray-300 hai-text-[#6e00ff] focus:hai-ring-[#6e00ff] hai-m-0 hai-p-0 hai-appearance-none">
                </div>
                <div class="hai-ml-3">
                  <label for="hai_enable_chat" class="hai-label hai-text-sm hai-font-medium hai-text-gray-900">
                    <?php echo esc_html__('Enable Chat Widget', 'hai-support'); ?>
                    <span class="hai-ml-2 hai-inline-flex hai-items-center hai-px-2 hai-py-0.5 hai-rounded-lg hai-text-xs hai-font-medium hai-bg-blue-100 hai-text-blue-800">Recommended</span>
                  </label>
                  <p class="hai-mt-3 hai-text-sm hai-text-gray-600">
                    <?php echo esc_html__('Show the chat widget on your website. Disable this if you want to temporarily turn off the chat.', 'hai-support'); ?>
                  </p>
                </div>
              </div>
            </div>

            <!-- Bot Name -->
            <div class="hai-bg-blue-50 hai-p-6 hai-rounded-xl hai-border hai-border-blue-100">
              <label for="hai_bot_name" class="hai-label hai-block hai-text-sm hai-font-medium hai-text-gray-900">
                <?php echo esc_html__('Bot Name', 'hai-support'); ?>
                <span class="hai-ml-2 hai-inline-flex hai-items-center hai-px-2 hai-py-0.5 hai-rounded-lg hai-text-xs hai-font-medium hai-bg-blue-100 hai-text-blue-800">Optional</span>
              </label>
              <div class="hai-mt-3">
                <input type="text"
                  name="hai_bot_name"
                  id="hai_bot_name"
                  value="<?php echo esc_attr(hai_get_setting('hai_bot_name')); ?>"
                  class="hai-block hai-w-full hai-rounded-lg hai-border hai-border-gray-300 focus:hai-border-[#6e00ff] focus:hai-ring-[#6e00ff] hai-text-sm hai-m-0 hai-px-3 hai-py-2 hai-bg-white"
                  placeholder="<?php echo esc_attr__('Enter bot name', 'hai-support'); ?>">
              </div>
              <p class="hai-mt-3 hai-text-sm hai-text-gray-600">
                <?php echo esc_html__('This name will be displayed in the chat widget. Default: Hai AI', 'hai-support'); ?>
              </p>
            </div>

            <!-- Agent Avatar -->
            <div class="hai-bg-blue-50 hai-p-6 hai-rounded-xl hai-border hai-border-blue-100">
              <label for="hai_agent_avatar" class="hai-label hai-block hai-text-sm hai-font-medium hai-text-gray-900">
                <?php echo esc_html__('Agent Avatar', 'hai-support'); ?>
                <span class="hai-ml-2 hai-inline-flex hai-items-center hai-px-2 hai-py-0.5 hai-rounded-lg hai-text-xs hai-font-medium hai-bg-blue-100 hai-text-blue-800">Optional</span>
              </label>
              <div class="hai-mt-3">
                <div class="hai-grid hai-grid-cols-4 hai-gap-4">
                  <?php
                  $current_avatar = hai_get_setting('hai_agent_avatar');
                  $default_avatar = 'agent1.png';
                  for ($i = 1; $i <= 8; $i++):
                    $avatar_file = "agent{$i}.png";
                    $is_selected = ($current_avatar ? $current_avatar === $avatar_file : $avatar_file === $default_avatar);
                  ?>
                    <label class="hai-relative hai-flex hai-flex-col hai-items-center hai-gap-2 hai-cursor-pointer">
                      <input type="radio"
                        name="hai_agent_avatar"
                        value="<?php echo esc_attr($avatar_file); ?>"
                        <?php checked($is_selected); ?>
                        class="hai-sr-only hai-peer">
                      <div class="hai-w-16 hai-h-16 hai-rounded-full hai-overflow-hidden hai-border-2 hai-transition-all peer-checked:hai-border-[#d702fc] hai-border-transparent">
                        <img src="<?php echo esc_url(HAI_SUPPORT_PLUGIN_URL . 'assets/images/avatars/' . $avatar_file); ?>"
                          alt="Agent <?php echo $i; ?>"
                          class="hai-w-full hai-h-full hai-object-cover">
                      </div>
                      <div class="hai-w-3 hai-h-3 hai-rounded-full hai-bg-[#d702fc] hai-opacity-0 peer-checked:hai-opacity-100 hai-transition-opacity"></div>
                    </label>
                  <?php endfor; ?>
                </div>
              </div>
              <p class="hai-mt-3 hai-text-sm hai-text-gray-600">
                <?php echo esc_html__('Choose an avatar for your AI agent. This will be displayed in the chat widget.', 'hai-support'); ?>
              </p>
            </div>

            <!-- Theme Color -->
            <div class="hai-bg-blue-50 hai-p-6 hai-rounded-xl hai-border hai-border-blue-100">
              <label for="hai_theme_color" class="hai-block hai-text-sm hai-font-medium hai-text-gray-900">
                <?php echo esc_html__('Theme Color', 'hai-support'); ?>
                <span class="hai-ml-2 hai-inline-flex hai-items-center hai-px-2 hai-py-0.5 hai-rounded-lg hai-text-xs hai-font-medium hai-bg-blue-100 hai-text-blue-800">Optional</span>
              </label>
              <div class="hai-mt-3 hai-flex hai-items-center hai-gap-3">
                <div class="hai-flex-shrink-0 hai-relative hai-rounded-lg hai-overflow-hidden hai-border hai-border-gray-300 hai-bg-white">
                  <input type="color"
                    name="hai_theme_color"
                    id="hai_theme_color"
                    value="<?php echo esc_attr(hai_get_setting('hai_theme_color')); ?>"
                    class="hai-h-10 hai-w-20 hai-cursor-pointer hai-border-none">
                </div>
                <input type="text"
                  id="hai_theme_color_text"
                  value="<?php echo esc_attr(hai_get_setting('hai_theme_color')); ?>"
                  class="hai-w-32 hai-rounded-lg hai-border-gray-300 hai-text-sm hai-font-mono hai-bg-white"
                  readonly>
              </div>
              <p class="hai-mt-3 hai-text-sm hai-text-gray-600">
                <?php echo esc_html__('Choose the primary color for the chat widget. Default: #d702fc', 'hai-support'); ?>
              </p>
            </div>
          </div>
        </div>

        <!-- Advanced Settings Section -->
        <div class="hai-p-6 lg:hai-p-8">
          <div class="hai-flex hai-items-start hai-gap-4 hai-mb-6">
            <div class="hai-flex-shrink-0 hai-w-12 hai-h-12 hai-rounded-xl hai-bg-gray-100 hai-flex hai-items-center hai-justify-center">
              <svg class="hai-w-6 hai-h-6 hai-text-gray-600" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="1.5" d="M9 3v2m6-2v2M9 19v2m6-2v2M5 9H3m2 6H3m18-6h-2m2 6h-2M7 19h10a2 2 0 002-2V7a2 2 0 00-2-2H7a2 2 0 00-2 2v10a2 2 0 002 2zM9 9h6v6H9V9z"></path>
              </svg>
            </div>
            <div>
              <h3 class="hai-h3 hai-text-lg hai-font-semibold hai-text-gray-900 hai-m-0 hai-p-0"><?php echo esc_html__('Advanced Settings', 'hai-support'); ?></h3>
              <p class="hai-mt-1 hai-text-sm hai-text-gray-500 hai-m-0 hai-p-0"><?php echo esc_html__('Optional settings for advanced customization.', 'hai-support'); ?></p>
            </div>
          </div>

          <div class="hai-space-y-6">
            <!-- Custom Prompt -->
            <div class="hai-bg-gray-50 hai-p-6 hai-rounded-xl hai-border hai-border-gray-200">
              <div class="hai-flex hai-items-start hai-justify-between hai-mb-4">
                <div>
                  <label for="hai_custom_prompt" class="hai-block hai-text-sm hai-font-medium hai-text-gray-900">
                    <?php echo esc_html__('Custom Prompt', 'hai-support'); ?>
                    <span class="hai-ml-2 hai-inline-flex hai-items-center hai-px-2 hai-py-0.5 hai-rounded-lg hai-text-xs hai-font-medium hai-bg-yellow-100 hai-text-yellow-800">Important</span>
                  </label>
                  <p class="hai-mt-1 hai-text-sm hai-text-gray-600">
                    <?php echo esc_html__('Define how your AI chatbot will behave and respond to users.', 'hai-support'); ?>
                  </p>
                </div>
                <button type="button"
                  id="hai-generate-prompt"
                  class="hai-inline-flex hai-items-center hai-justify-center hai-rounded-lg hai-bg-[#6e00ff] hai-px-4 hai-py-2 hai-text-sm hai-font-medium hai-text-white hai-transition-all hai-duration-200 hover:hai-bg-[#5b00d6] hover:hai-translate-y-[-1px] hover:hai-shadow-[0_4px_8px_-2px_rgba(110,0,255,0.3)] focus:hai-outline-none hai-border-0 hai-cursor-pointer hai-m-0">
                  <svg class="hai-w-4 hai-h-4 hai-mr-1.5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M19.428 15.428a2 2 0 00-1.022-.547l-2.387-.477a6 6 0 00-3.86.517l-.318.158a6 6 0 01-3.86.517L6.05 15.21a2 2 0 00-1.806.547M8 4h8l-1 1v5.172a2 2 0 00.586 1.414l5 5c1.26 1.26.367 3.414-1.415 3.414H4.828c-1.782 0-2.674-2.154-1.414-3.414l5-5A2 2 0 009 10.172V5L8 4z"></path>
                  </svg>
                  <?php echo esc_html__('Generate Prompt', 'hai-support'); ?>
                </button>
              </div>

              <!-- Status Message -->
              <div id="hai-prompt-status" class="hai-hidden hai-mb-4 hai-rounded-lg hai-p-3 hai-text-sm hai-flex hai-items-center hai-gap-2">
                <div class="hai-flex-shrink-0">
                  <svg class="hai-w-5 hai-h-5" fill="none" stroke="currentColor" viewBox="0 0 24 24"></svg>
                </div>
                <div class="hai-flex-1 hai-min-w-0">
                  <p class="hai-m-0 hai-p-0"></p>
                </div>
              </div>

              <!-- Warning Message -->
              <div class="hai-mb-4 hai-rounded-lg hai-bg-yellow-50 hai-p-4 hai-border hai-border-yellow-100">
                <div class="hai-flex hai-items-start hai-gap-3">
                  <svg class="hai-flex-shrink-0 hai-w-5 hai-h-5 hai-text-yellow-400" viewBox="0 0 20 20" fill="currentColor">
                    <path fill-rule="evenodd" d="M8.485 2.495c.673-1.167 2.357-1.167 3.03 0l6.28 10.875c.673 1.167-.17 2.625-1.516 2.625H3.72c-1.347 0-2.189-1.458-1.515-2.625L8.485 2.495zM10 5a.75.75 0 01.75.75v4.5a.75.75 0 01-1.5 0v-4.5A.75.75 0 0110 5zm0 10a1 1 0 100-2 1 1 0 000 2z" clip-rule="evenodd" />
                  </svg>
                  <p class="hai-text-sm hai-text-yellow-700 hai-m-0">
                    <?php echo esc_html__('Please review and customize this generated prompt before saving. The AI assistant will use this exact prompt to interact with your users. Make sure it accurately represents your website, services, and desired interaction style.', 'hai-support'); ?>
                  </p>
                </div>
              </div>

              <!-- Prompt Textarea -->
              <div class="hai-relative">
                <textarea name="hai_custom_prompt"
                  id="hai_custom_prompt"
                  rows="12"
                  class="hai-block hai-w-full hai-rounded-lg hai-border hai-border-gray-300 focus:hai-border-[#6e00ff] focus:hai-ring-[#6e00ff] hai-text-sm hai-m-0 hai-px-3 hai-py-2 hai-bg-white hai-resize-y hai-min-h-[300px]"
                  placeholder="<?php echo esc_attr__('Enter custom instructions for the AI chatbot behavior', 'hai-support'); ?>"><?php echo esc_textarea(hai_get_setting('hai_custom_prompt')); ?></textarea>
              </div>
            </div>

            <!-- IPInfo API Key -->
            <div class="hai-bg-gray-50 hai-p-6 hai-rounded-xl hai-border hai-border-gray-200">
              <label for="hai_ipinfo_api_key" class="hai-block hai-text-sm hai-font-medium hai-text-gray-900">
                <?php echo esc_html__('IPInfo API Key', 'hai-support'); ?>
                <span class="hai-ml-2 hai-inline-flex hai-items-center hai-px-2 hai-py-0.5 hai-rounded-lg hai-text-xs hai-font-medium hai-bg-gray-100 hai-text-gray-800">Optional</span>
              </label>
              <div class="hai-mt-3">
                <input type="text"
                  name="hai_ipinfo_api_key"
                  id="hai_ipinfo_api_key"
                  value="<?php echo esc_attr(hai_get_setting('hai_ipinfo_api_key')); ?>"
                  class="hai-block hai-w-full hai-rounded-lg hai-border-gray-300 focus:hai-border-[#6e00ff] focus:hai-ring-[#6e00ff] hai-text-sm hai-font-mono hai-bg-white"
                  placeholder="<?php echo esc_attr__('Enter your IPInfo API key', 'hai-support'); ?>">
              </div>
              <p class="hai-mt-3 hai-text-sm hai-text-gray-600">
                <?php echo esc_html__('Optional: Add an IPInfo API key for enhanced visitor location data. Get your key from', 'hai-support'); ?>
                <a href="https://ipinfo.io/" target="_blank" class="hai-text-[#6e00ff] hai-underline">IPInfo</a>.
              </p>
            </div>
          </div>
        </div>

        <!-- Submit Button -->
        <div class="hai-px-6 hai-py-4 lg:hai-px-8 lg:hai-py-5 hai-bg-gray-50">
          <div class="hai-flex hai-justify-between hai-items-center">
            <div class="hai-text-sm hai-text-gray-500">
              <span class="hai-text-red-600">*</span> <?php echo esc_html__('Required fields', 'hai-support'); ?>
            </div>
            <button type="submit" class="hai-inline-flex hai-items-center hai-rounded-lg hai-bg-[#d702fc] hai-px-5 hai-py-2.5 hai-text-sm hai-font-medium hai-text-white hai-transition-all hai-duration-200 hover:hai-bg-[#b502d6] hover:hai-translate-y-[-1px] hover:hai-shadow-[0_4px_8px_-2px_rgba(215,2,252,0.3)] focus:hai-outline-none hai-border-0 hai-cursor-pointer hai-m-0">
              <svg class="hai-w-4 hai-h-4 hai-mr-1.5" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"></path>
              </svg>
              <?php echo esc_html__('Save Settings', 'hai-support'); ?>
            </button>
          </div>
        </div>
      </form>
    </div>
  </div>
</div>

<?php require_once HAI_SUPPORT_PLUGIN_DIR . 'templates/admin-footer.php'; ?>